@@ -19,13 +19,13 @@ import shutil
 import os
 from calculate.lib.utils.files import listDirectory, readFile, readLinesFile, \
     makeDirectory, removeDir
-from calculate.lib.utils.portage import Git
+from calculate.lib.utils.git import Git
 from update import UpdateError
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_update3', sys.modules[__name__])
 
-DEFAULT_BRANCH = "master"
+DEFAULT_BRANCH = Git.Reference.Master
 
 
 class RepositoryStorage(object):
@@ -82,9 +82,8 @@ class RepositoryStorageSet(RepositoryStorage):
     """
     Набор хранилищ репозиториев
     """
-    def __init__(self):
-        self.storages = [LocalStorage('/var/lib/layman'),
-                         CacheStorage('/var/calculate/tmp/update')]
+    def __init__(self, *storages):
+        self.storages = storages
 
     def get_profiles(self, url, branch=DEFAULT_BRANCH):
         """
@@ -193,9 +192,10 @@ class ProfileRepository(object):
         repo_name = pr.repo_name
         if name != repo_name:
             rpath_new = path.join(storage.directory, repo_name)
-            if not path.exists(rpath_new):
-                os.rename(rpath, rpath_new)
-                pr = cls(repo_name, storage)
+            if path.exists(rpath_new):
+                removeDir(rpath_new)
+            shutil.move(rpath, rpath_new)
+            pr = cls(repo_name, storage)
         return pr
 
     @property
